@@ -690,8 +690,6 @@ class OWxpower(XoppyWidget):
         roughness_str += "]"
         flags_str += "]"
 
-
-
         if self.MATERIAL_CONSTANT_LIBRARY_FLAG == 0:
             material_constants_library = xraylib
             material_constants_library_str = "xraylib"
@@ -709,7 +707,7 @@ class OWxpower(XoppyWidget):
             dens                       = dens     ,
             roughness                  = roughness,
             flags                      = flags    ,
-            NELEMENTS                  = self.NELEMENTS + 1,
+            nelements                  = self.NELEMENTS + 1,
             FILE_DUMP                  = self.FILE_DUMP,
             material_constants_library = material_constants_library,
                                                 )
@@ -723,7 +721,7 @@ class OWxpower(XoppyWidget):
             "dens"                      : dens_str,
             "roughness"                 : roughness_str,
             "flags"                     : flags_str,
-            "NELEMENTS"                 : self.NELEMENTS + 1,
+            "nelements"                 : self.NELEMENTS + 1,
             "FILE_DUMP"                 : self.FILE_DUMP,
             "material_constants_library": material_constants_library_str,
         }
@@ -757,7 +755,7 @@ out_dictionary = xoppy_calc_power(
         dens      = {dens},
         roughness = {roughness}, # in A (for mirrors)
         flags     = {flags}, # 0=Filter, 1=Mirror
-        NELEMENTS = {NELEMENTS},
+        nelements = {nelements},
         FILE_DUMP = {FILE_DUMP},
         material_constants_library = {material_constants_library},
         )
@@ -793,13 +791,18 @@ plot(out_dictionary["data"][0,:], out_dictionary["data"][1,:],
 
         try:
             calculated_data.add_content("xoppy_data", out_dictionary["data"].T)
+        except:
+            pass
+        try:
             calculated_data.add_content("plot_x_col", 0)
             calculated_data.add_content("plot_y_col", -1)
+        except:
+            pass
+        try:
             calculated_data.add_content("xoppy_script", script)
         except:
             pass
         try:
-            # print(out_dictionary["labels"])
             calculated_data.add_content("labels", out_dictionary["labels"])
         except:
             pass
